@@ -182,19 +182,22 @@ $$ LANGUAGE PLPGSQL;
 COMMENT ON FUNCTION eoy_reopen_books(in_end_date date) IS
 $$ Removes checkpoints and reverses yearend transactions on in_end_date$$;
 
-CREATE OR REPLACE FUNCTION eoy__reopen_books_at(in_reopen_date date) 
+CREATE OR REPLACE FUNCTION eoy__reopen_books_at(in_reopen_date date)
 RETURNS BOOL
 LANGUAGE SQL AS
 $$
 
-    SELECT eoy_reopen_books(end_date) 
-      FROM (SELECT end_date 
-              FROM account_checkpoint
-             WHERE end_date >= $1
-             GROUP BY end_date) eoy_dates
-  ORDER BY end_date;
+  WITH eoy_dates AS (
+      SELECT end_date
+        FROM account_checkpoint
+       WHERE end_date >= $1
+    GROUP BY end_date
+    ORDER BY end_date DESC
+    )
+    SELECT eoy_reopen_books(end_date)
+      FROM eoy_dates;
 
-SELECT CASE WHEN (SELECT count(*) > 0 from account_checkpoint 
+SELECT CASE WHEN (SELECT count(*) > 0 from account_checkpoint
                    where end_date = $1 - 1)
             THEN true
             ELSE eoy_create_checkpoint($1 - 1) > 0
